@@ -7,6 +7,8 @@
 #include <QProcess>
 #include <QSettings>
 #include <QShortcut>
+#include <QMenuBar>
+#include <QMenu>
 
 #include "ui_applicationswindow.h"
 #include "descriptivedelegate.h"
