@@ -4,6 +4,7 @@
 #include <QDebug>
 
 #include <QDialog>
+#include <QDesktopWidget>
 #include <QRegExpValidator>
 #include <QFileInfo>
 #include <QDateTime>
@@ -32,6 +33,7 @@ private:
     QString user;
 
 private slots:
+    void onOrientationChanged();
     void save();
 };
 
