@@ -36,7 +36,9 @@ public:
     QString currentPath();
 
     void setDetails(FileSystemModel::Detail firstDetail, FileSystemModel::Detail secondDetail);
-    void setSavedPosition(int savedPosition);
+    void setResumePosition(int resumePosition);
+
+    int position();
 
 public slots:
     void openPath(QString path);
@@ -70,7 +72,7 @@ private:
     int fromGridPosition(int gridPosition);
 
     FileSystemModel *filesystemModel;
-    int savedPosition;
+    int resumePosition;
 
 private slots:
     void onActivated(QModelIndex index);
