@@ -17,6 +17,9 @@
 #include <QHBoxLayout>
 #include <QStringList>
 #include <QList>
+#include <QSettings>
+
+#include "global.h"
 
 class LocationWidget : public QScrollArea
 {
@@ -28,6 +31,7 @@ public:
 
     int setLocation(QString path, int oldPosition);
     bool isEditorEnabled();
+    void reloadSettings();
 
 public slots:
     void enableEditor();
@@ -40,12 +44,15 @@ signals:
 private:
     void resizeEvent(QResizeEvent *e);
 
+    bool isEditorPersistent();
+
     QAbstractButton* createButton(QString name);
     QAbstractButton *checkedButton;
     void centerCheckedButton();
 
     QWidget *buttonWidget;
     QWidget *editorWidget;
+    QToolButton *locationUpButton;
     QLineEdit *locationEdit;
 
     QString currentPath;
@@ -54,6 +61,7 @@ private:
 
 private slots:
     void onButtonClicked();
+    void goUp();
 };
 
 #endif // LOCATIONWIDGET_H
