@@ -89,6 +89,8 @@ MainWindow::MainWindow(QFileInfo startingLocation) :
 
     // Other shortcuts
     connect(new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_L), this), SIGNAL(activated()), ui->locationWidget, SLOT(enableEditor()));
+    connect(new QShortcut(QKeySequence(Qt::Key_Backspace), this), SIGNAL(activated()), this, SLOT(goBack()));
+    connect(new QShortcut(QKeySequence(Qt::SHIFT + Qt::Key_Backspace), this), SIGNAL(activated()), this, SLOT(goForward()));
 
     // Operation manager prompts
     connect(OperationManager::get(), SIGNAL(overwriteSituation(int,FileOperation::Type,QString,QString)),
@@ -112,9 +114,12 @@ MainWindow::MainWindow(QFileInfo startingLocation) :
     // Should be called before setting the initial location, to avoid unnecessary file listings
     reloadSettings();
 
+    // Check whether the standard starting location should be overriden
+    const bool standardStartingLocation = !startingLocation.exists() || !startingLocation.isDir();
+
     // Determine location for the initial view
-    if (!startingLocation.exists() || !startingLocation.isDir()) {
-        // Recover from invalid location in the argument
+    if (standardStartingLocation) {
+        // Custom location was invalid or not set, load from settings
         startingLocation = QSettings().value("Main/StartingLocation", DEFAULT_StartingLocation).toString();
         if (!startingLocation.exists() || !startingLocation.isDir()) {
             // Recover from invalid location in the settings
@@ -130,7 +135,7 @@ MainWindow::MainWindow(QFileInfo startingLocation) :
     ui->browserList->openPath(startingLocation.absoluteFilePath());
 
     // Start in bookmarks if configured to do so
-    if (QSettings().value("Main/StartInBookmarks", DEFAULT_StartInBookmarks).toBool())
+    if (standardStartingLocation && QSettings().value("Main/StartInBookmarks", DEFAULT_StartInBookmarks).toBool())
         showBookmarks();
 }
 
@@ -241,6 +246,8 @@ void MainWindow::reloadSettings()
 
     ui->browserList->setDetails(static_cast<FileSystemModel::Detail>(QSettings().value("Browser/FirstDetail", DEFAULT_FirstDetail).toInt()),
                                 static_cast<FileSystemModel::Detail>(QSettings().value("Browser/SecondDetail", DEFAULT_SecondDetail).toInt()));
+
+    ui->locationWidget->reloadSettings();
 }
 
 QMainWindow* MainWindow::findTopWindow()
@@ -270,9 +277,11 @@ void MainWindow::closeSearch()
 // Update the displayed path
 void MainWindow::onLocationChanged(QString path, int oldPosition)
 {
+    history.add(path);
+
     closeSearch();
     ui->selectionToggleButton->setChecked(false);
-    ui->browserList->setSavedPosition(ui->locationWidget->setLocation(path, oldPosition));
+    ui->browserList->setResumePosition(ui->locationWidget->setLocation(path, oldPosition));
     ui->locationLabel->setText(QFontMetrics(ui->locationLabel->font()).elidedText(path, Qt::ElideLeft, ui->locationLabel->width()));
 }
 
@@ -381,3 +390,27 @@ void MainWindow::onSelectClicked()
     ui->selectionToggleButton->setChecked(true);
     ui->browserList->selectAll();
 }
+
+void MainWindow::goBack()
+{
+    history.setPosition(ui->browserList->position());
+
+    HistoryItem location = history.back();
+
+    if (!location.path.isNull()) {
+        ui->browserList->openPath(location.path);
+        ui->browserList->setResumePosition(location.position);
+    }
+}
+
+void MainWindow::goForward()
+{
+    history.setPosition(ui->browserList->position());
+
+    HistoryItem location = history.forward();
+
+    if (!location.path.isNull()) {
+        ui->browserList->openPath(location.path);
+        ui->browserList->setResumePosition(location.position);
+    }
+}
