@@ -25,7 +25,7 @@ public:
 private:
     Ui::OperationsWindow *ui;
 
-    int activeOperationsCount;
+    int livingOperationsCount;
 
     QListWidgetItem* findOperationById(int id);
 
